summaryrefslogtreecommitdiffstats
path: root/kget/logwindow.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
commit937b2991d8e78166eea904c80ad04d34607017a4 (patch)
tree2accb8161eab09df5d7a5484ea9ea080ad123168 /kget/logwindow.cpp
parentdba26cb985af370c33d1767037851705cc561726 (diff)
downloadtdenetwork-937b2991d8e78166eea904c80ad04d34607017a4.tar.gz
tdenetwork-937b2991d8e78166eea904c80ad04d34607017a4.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1246075 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kget/logwindow.cpp')
-rw-r--r--kget/logwindow.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kget/logwindow.cpp b/kget/logwindow.cpp
index 7ce11939..b87743ed 100644
--- a/kget/logwindow.cpp
+++ b/kget/logwindow.cpp
@@ -45,8 +45,8 @@
// res.simplifyWhiteSpace();
// int pos;
-// while ( (pos = res.tqfind(' ')) != -1) {
-// res.tqreplace(pos, 1, new TQChar( 0x00a0 ), 1);
+// while ( (pos = res.find(' ')) != -1) {
+// res.replace(pos, 1, new TQChar( 0x00a0 ), 1);
// }
// return res;
@@ -58,14 +58,14 @@ static TQString removeHTML(const TQString & str)
TQString res = str;
int pos;
- // tqreplace <br/> with a newline
- while ((pos = res.tqfind("<br/>")) != -1) {
- res.tqreplace(pos, 4, "\n");
+ // replace <br/> with a newline
+ while ((pos = res.find("<br/>")) != -1) {
+ res.replace(pos, 4, "\n");
}
// remove all tags
- while ((pos = res.tqfind('<')) != -1) {
- int pos2 = res.tqfind('>', pos);
+ while ((pos = res.find('<')) != -1) {
+ int pos2 = res.find('>', pos);
if (pos2 == -1) {
pos2 = res.length() + 1;
@@ -112,7 +112,7 @@ SeparatedLog::SeparatedLog(TQWidget * tqparent):TQWidget(tqparent)
void SeparatedLog::addLog(uint id, const TQString & filename, const TQString & message)
{
- if (!trMap.tqcontains(id)) {
+ if (!trMap.contains(id)) {
trMap.insert(id, message);
TQListViewItem *last=lv_log->lastItem();
new TQListViewItem(lv_log, last);